@@ -9,12 +9,12 @@ from sqlalchemy.orm import Session
 
 
 @contextmanager
-def session_scope(bind: Engine) -> Generator[Session, Engine, None]:
+def session_scope(bind: Engine, *args, **kwargs) -> Generator[Session, Engine, None]:
     """Provide a transactional scope around a series of database operations.
 
     src: https://docs.sqlalchemy.org/en/13/orm/session_basics.html
     """
-    session = Session(bind=bind)
+    session = Session(bind=bind, expire_on_commit=False, *args, **kwargs)
     try:
         yield session
         session.commit()
